@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2003 CodeFactory AB
- * Copyright (C) 2003 Mikael Hallendal <micke@codefactory.se>
+ * Copyright (C) 2003 Mikael Hallendal <micke@imendio.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -24,15 +24,9 @@
 
 #include <glib.h>
 
-gboolean  dh_parse_file (const gchar  *path,
-			 GNode        *book_tree,
-			 GList       **keywords,
-			 GError      **error);
-#ifdef HAVE_LIBZ
-gboolean  dh_parse_gz_file (const gchar  *path,
-			 GNode        *book_tree,
-			 GList       **keywords,
-			 GError      **error);
-#endif
+gboolean  dh_parser_read_file (const gchar  *path,
+			       GNode        *book_tree,
+			       GList       **keywords,
+			       GError      **error);
 
 #endif /* __DH_PARSER_H__ */
